==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/AggregateRouteConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * List of IPv4 and IPv6 route configurations.
 * @property ipv4Routes List of IPv4 Route prefixes.
 * @property ipv6Routes List of IPv6 Routes prefixes.
 */
public data class AggregateRouteConfigurationArgs(
    public val ipv4Routes: Output<List<AggregateRouteArgs>>? = null,
    public val ipv6Routes: Output<List<AggregateRouteArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs.builder()
            .ipv4Routes(
                ipv4Routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipv6Routes(
                ipv6Routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AggregateRouteConfigurationArgs].
 */
@PulumiTagMarker
public class AggregateRouteConfigurationArgsBuilder internal constructor() {
    private var ipv4Routes: Output<List<AggregateRouteArgs>>? = null

    private var ipv6Routes: Output<List<AggregateRouteArgs>>? = null

    /**
     * @param value List of IPv4 Route prefixes.
     */
    @JvmName("tmvddcrndvjytaqj")
    public suspend fun ipv4Routes(`value`: Output<List<AggregateRouteArgs>>) {
        this.ipv4Routes = value
    }

    @JvmName("agiqmbjdprseuaow")
    public suspend fun ipv4Routes(vararg values: Output<AggregateRouteArgs>) {
        this.ipv4Routes = Output.all(values.asList())
    }

    /**
     * @param values List of IPv4 Route prefixes.
     */
    @JvmName("rnprkruxdqgnlrnj")
    public suspend fun ipv4Routes(values: List<Output<AggregateRouteArgs>>) {
        this.ipv4Routes = Output.all(values)
    }

    /**
     * @param value List of IPv6 Routes prefixes.
     */
    @JvmName("nkpudfdriovblyhw")
    public suspend fun ipv6Routes(`value`: Output<List<AggregateRouteArgs>>) {
        this.ipv6Routes = value
    }

    @JvmName("pfbdtmhxiwludocb")
    public suspend fun ipv6Routes(vararg values: Output<AggregateRouteArgs>) {
        this.ipv6Routes = Output.all(values.asList())
    }

    /**
     * @param values List of IPv6 Routes prefixes.
     */
    @JvmName("mwjpbqyxumswtvlf")
    public suspend fun ipv6Routes(values: List<Output<AggregateRouteArgs>>) {
        this.ipv6Routes = Output.all(values)
    }

    /**
     * @param value List of IPv4 Route prefixes.
     */
    @JvmName("luirubohcxjxxsnk")
    public suspend fun ipv4Routes(`value`: List<AggregateRouteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("gjasyhpfcnwpwjfy")
    public suspend fun ipv4Routes(argument: List<suspend AggregateRouteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("jvwbuohfestargdy")
    public suspend fun ipv4Routes(vararg argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("fptwhuahbmmovbxh")
    public suspend fun ipv4Routes(argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AggregateRouteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param values List of IPv4 Route prefixes.
     */
    @JvmName("kcolsvaxvvsobcyl")
    public suspend fun ipv4Routes(vararg values: AggregateRouteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4Routes = mapped
    }

    /**
     * @param value List of IPv6 Routes prefixes.
     */
    @JvmName("utuynyxbbdhcfvrf")
    public suspend fun ipv6Routes(`value`: List<AggregateRouteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("unbeurnxeqvrlgcb")
    public suspend fun ipv6Routes(argument: List<suspend AggregateRouteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("nvaheyajvyesteih")
    public suspend fun ipv6Routes(vararg argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("djicadbbgekblpty")
    public suspend fun ipv6Routes(argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AggregateRouteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param values List of IPv6 Routes prefixes.
     */
    @JvmName("esdxkhepofctmwna")
    public suspend fun ipv6Routes(vararg values: AggregateRouteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6Routes = mapped
    }

    internal fun build(): AggregateRouteConfigurationArgs = AggregateRouteConfigurationArgs(
        ipv4Routes = ipv4Routes,
        ipv6Routes = ipv6Routes,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/AggregateRouteConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * List of IPv4 and IPv6 route configurations.
 * @property ipv4Routes List of IPv4 Route prefixes.
 * @property ipv6Routes List of IPv6 Routes prefixes.
 */
public data class AggregateRouteConfigurationArgs(
    public val ipv4Routes: Output<List<AggregateRouteArgs>>? = null,
    public val ipv6Routes: Output<List<AggregateRouteArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.AggregateRouteConfigurationArgs.builder()
            .ipv4Routes(
                ipv4Routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ipv6Routes(
                ipv6Routes?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [AggregateRouteConfigurationArgs].
 */
@PulumiTagMarker
public class AggregateRouteConfigurationArgsBuilder internal constructor() {
    private var ipv4Routes: Output<List<AggregateRouteArgs>>? = null

    private var ipv6Routes: Output<List<AggregateRouteArgs>>? = null

    /**
     * @param value List of IPv4 Route prefixes.
     */
    @JvmName("ikpsowpywoumjxsb")
    public suspend fun ipv4Routes(`value`: Output<List<AggregateRouteArgs>>) {
        this.ipv4Routes = value
    }

    @JvmName("wnqxiipolyqutejq")
    public suspend fun ipv4Routes(vararg values: Output<AggregateRouteArgs>) {
        this.ipv4Routes = Output.all(values.asList())
    }

    /**
     * @param values List of IPv4 Route prefixes.
     */
    @JvmName("rdfkwbtvbnxdfujf")
    public suspend fun ipv4Routes(values: List<Output<AggregateRouteArgs>>) {
        this.ipv4Routes = Output.all(values)
    }

    /**
     * @param value List of IPv6 Routes prefixes.
     */
    @JvmName("clbndkemfncfnnfx")
    public suspend fun ipv6Routes(`value`: Output<List<AggregateRouteArgs>>) {
        this.ipv6Routes = value
    }

    @JvmName("davhyhamfcyhkers")
    public suspend fun ipv6Routes(vararg values: Output<AggregateRouteArgs>) {
        this.ipv6Routes = Output.all(values.asList())
    }

    /**
     * @param values List of IPv6 Routes prefixes.
     */
    @JvmName("edossnihnthtfgrf")
    public suspend fun ipv6Routes(values: List<Output<AggregateRouteArgs>>) {
        this.ipv6Routes = Output.all(values)
    }

    /**
     * @param value List of IPv4 Route prefixes.
     */
    @JvmName("hbkgkxsgfukxvuli")
    public suspend fun ipv4Routes(`value`: List<AggregateRouteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("smwgukehjcpnjfwq")
    public suspend fun ipv4Routes(argument: List<suspend AggregateRouteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("dmgogmcfpfifxeyw")
    public suspend fun ipv4Routes(vararg argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param argument List of IPv4 Route prefixes.
     */
    @JvmName("kywhhertirexnqwm")
    public suspend fun ipv4Routes(argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AggregateRouteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipv4Routes = mapped
    }

    /**
     * @param values List of IPv4 Route prefixes.
     */
    @JvmName("gjfnappcpkahkvbd")
    public suspend fun ipv4Routes(vararg values: AggregateRouteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv4Routes = mapped
    }

    /**
     * @param value List of IPv6 Routes prefixes.
     */
    @JvmName("wegqxrjfptayxqhr")
    public suspend fun ipv6Routes(`value`: List<AggregateRouteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("jicdlprquyxbglwg")
    public suspend fun ipv6Routes(argument: List<suspend AggregateRouteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("wsiohfiqpkqxbaqf")
    public suspend fun ipv6Routes(vararg argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            AggregateRouteArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param argument List of IPv6 Routes prefixes.
     */
    @JvmName("slbaqjtpcxyrauig")
    public suspend fun ipv6Routes(argument: suspend AggregateRouteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(AggregateRouteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipv6Routes = mapped
    }

    /**
     * @param values List of IPv6 Routes prefixes.
     */
    @JvmName("ekpbaacruesvpgny")
    public suspend fun ipv6Routes(vararg values: AggregateRouteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipv6Routes = mapped
    }

    internal fun build(): AggregateRouteConfigurationArgs = AggregateRouteConfigurationArgs(
        ipv4Routes = ipv4Routes,
        ipv6Routes = ipv6Routes,
    )
}
